API Gateway: Cliente de API en Python
=====================================

.. image:: https://badge.fury.io/py/apigatewaycl.svg
    :target: https://pypi.org/project/apigatewaycl
.. image:: https://img.shields.io/pypi/status/apigatewaycl.svg
    :target: https://pypi.org/project/apigatewaycl
.. image:: https://img.shields.io/pypi/pyversions/apigatewaycl.svg
    :target: https://pypi.org/project/apigatewaycl
.. image:: https://scrutinizer-ci.com/g/apigatewaycl/apigateway-api-client-python/badges/quality-score.png?b=master
    :target: https://scrutinizer-ci.com/g/apigatewaycl/apigateway-api-client-python/
.. image:: https://scrutinizer-ci.com/g/apigatewaycl/apigateway-api-client-python/badges/coverage.png?b=master
    :target: https://scrutinizer-ci.com/g/apigatewaycl/apigateway-api-client-python/
.. image:: https://img.shields.io/pypi/l/apigatewaycl.svg
    :target: https://raw.githubusercontent.com/apigatewaycl/apigateway-api-client-python/master/COPYING

Cliente para realizar la integración con los servicios web de `API Gateway <https://www.apigateway.cl>`_ desde Python.

Revisa la `documentación <https://api-client-python.docs.apigateway.cl>`_ de la biblioteca para más información, sus características y detalles de su uso.

Licencia
--------

Este programa es software libre: usted puede redistribuirlo y/o modificarlo
bajo los términos de la GNU Lesser General Public License (LGPL) publicada
por la Fundación para el Software Libre, ya sea la versión 3 de la Licencia,
o (a su elección) cualquier versión posterior de la misma.

Este programa se distribuye con la esperanza de que sea útil, pero SIN
GARANTÍA ALGUNA; ni siquiera la garantía implícita MERCANTIL o de APTITUD
PARA UN PROPÓSITO DETERMINADO. Consulte los detalles de la GNU Lesser General
Public License (LGPL) para obtener una información más detallada.

Debería haber recibido una copia de la GNU Lesser General Public License
(LGPL) junto a este programa. En caso contrario, consulte
`GNU Lesser General Public License <http://www.gnu.org/licenses/lgpl.html>`_.

Enlaces
-------

- `Sitio web API Gateway <https://www.apigateway.cl>`_.
- `Código fuente en GitHub <https://github.com/apigatewaycl/apigateway-api-client-python>`_.
- `Paquete en PyPI <https://pypi.org/project/apigatewaycl>`_.
- `Documentación en Read the Docs <https://apigatewaycl.readthedocs.io/es/latest>`_.
